header {
    position: absolute;
    width: 100%;
    z-index: 999;
    background-position: center;
    background-size: cover;
}

.bg {
    background-color: rgba(11, 97, 45, 0.52);
}

.top-alert {
    background-color: #262c38;
    color: #fff;
    display: none;
    justify-content: center;
    align-items: center;
    padding: 8px;
}


.top-alert-text {
    padding: 0 20px;
}

.top-alert-button {
    border: none;
}

.top-alert-cancel {
    height: 20px;
    width: 20px;
    cursor: pointer;
    margin: 0 20px;
}

.top-nav-wrapper {
    border-bottom: 1px solid #fff;
}

.top-nav {
    height: 160px;
    padding: 20px 0;
    margin-bottom: 0 !important;
}

.top-nav-item {
    color: #fff;
    font-size: 14px;
    text-transform: uppercase;
    font-weight: bold;
    margin-left: 8px;
    display: flex;
    justify-content: center;
    align-items: center;
}

.top-nav-dropdown {
    min-width: 120px;
    width: 120px;
    z-index: 999;
}

.search-input {
    width: 200px;
    margin: 0 !important;
    cursor: pointer;
}

.search-trigger {
    display: flex;
    align-items: center;
}

.contact-us-btn {
    color: #0b612d;

}

.contact-us-btn:hover, .contact-us-btn:focus {
    color: #5d6572 !important;
}

.top-nav-item {
    cursor: pointer;
}

.top-nav-item:hover {
    color: #fff;
}

.main-logo img {
    width: 257px;
}


.navbar {
    background-color: transparent;
    min-height: 52px;
}

.navbar-dropdown .navbar-item {
    padding-top: 1rem;
    padding-bottom: 1rem;

}


#mainNavbar.navbar-menu {
    justify-content: center
}

.navbar-menu.is-active {
    position: absolute;
    width: 100%;
}


#mainNavbar .navbar-dropdown .navbar-item {
    color: #5d6572;
}

#mainNavbar .navbar-start {
    margin-right: 0;
}


.nav-item-title {
    margin: 0 20px;
    text-transform: uppercase;
    font-weight: bold;
    color: #fff;
    font-family: Helvetica;
}

.nav-item-title.active,
.nav-item-title:hover,
.nav-item-title:focus,
.nav-item-title:focus-within {
    border-top: 2px solid #fff;
    color: #fff !important;

}

.navbar-brand {
    display: flex;
    justify-content: space-between;
}

.user-display {
    display: flex;
    align-items: center;

}


.navbar-brand .navbar-item img {
    max-height: 80px;
}

/* .navbar-burger {
    color: #fff;
} */

.navbar-burger span {
    height: 2px;
}

.navbar-burger:hover {
    color: #fff;
}


.megamenu {
    min-width: 600px;
    padding: 30px;
}


.megamenu .navbar-item {
    padding: 5px 0 !important;
    white-space: normal;
    align-items: flex-start;
    display: flex;
}

.megamenu .navbar-item svg {
    margin-right: 16px;
    height: 36px;
    width: 36px;
    background-color: rgba(0, 153, 151, 0.1);
    padding: 5px;
    max-height: 36px;
}



.alert {
    font-size: 14px
}

@media screen and (min-width: 768px) {
    .navbar-container{
        max-width: none!important;
        padding-left: 32px;
        padding-right: 32px;
        width: 100%;
    }
}


@media screen and (max-width: 768px) {
    .navbar-brand img{
        max-width: 200px;
    }
    .top-alert {
        justify-content: space-between;
    }

    .navbar.bottom-nav{
        min-height: 0;
    }

    .top-alert-text {
        padding: 0 0 0 6px;
        font-size: 12px;
    }

    .top-alert-button {
        padding: 4px 10px !important;
        font-size: 11px;
    }

    .top-alert-cancel {
        margin: 0 5px 0 20px;
    }

    .top-nav-wrapper {
        border: none;
    }


    .nav-item-title {
        color: #5d6572;
        margin: 0;
    }

    .megamenu {
        min-width: 100%;
    }
}


.navbar-item svg path{
    fill: currentColor !important

 }
