{% extends 'base.html' %}
{% load wagtailcore_tags static %}

{% block extra_css %}
{{ block.super }}

<link href='https://unpkg.com/maplibre-gl@2.4.0/dist/maplibre-gl.css' rel='stylesheet' />
<link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bulma@0.9.4/css/bulma.min.css">
<link rel="stylesheet" type="text/css" href="{% static 'css/header.css' %}">
<link rel="stylesheet" type="text/css" href="{% static 'css/style.css' %}">



<style>
  .tabs li a {
    color: rgb(239, 239, 239);
  }
  .tabs.is-active {
    color: #333;
  }
  .tab-content {
    padding: 1rem;
    display: none;
  }

  .tab-content.is-active {
    display: block;
  }

  #detail-map {
    min-height: 480px;
    width: 100%;
  }


  #autoresizing {
    display: block;
    overflow: hidden;
    resize: none;
  }
</style>
{% endblock %} 


{% block content %}

<main class="is-index">

  <section class="featured-event-section">
      <div class="container">
          {% comment %} <h2 class="section-title center">Latest Alert</h2> {% endcomment %}
          {% include 'capeditor/alert_item_include.html' with item_title=page.title item_url=page.url item_info=page.alert_info.all item_identifier=page.identifier %}
      </div>
  </section>


</main>
{% endblock content %} 


